Discover Packages
github.com/Jac0bDeal/sugoku
internal
cli
package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Aug 18, 2022
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
App is the CLI application.
NewApp constructs and returns an App from the passed env variables and flags.
Run runs the CLI application.
type Globals struct {
LogLevel string `short:"l" help:"Set the logging level (debug|info|warn|error|fatal)" default:"info"`
Version versionFlag `name:"version" help:"Print version information and quit"`
}
Globals contains the global flags for the CLI.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.